spectrum module
====================================

This module contains codes for creating spectra from the AtomDB emissivity files

.. automodule:: pyatomdb.spectrum
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:
